# Dataphin JDBC

## 版本

````
 Version:        4.4.0
 ReleaseDate:    2024-10-23
 GitCommit:      42aa68fae51d13c1b79f750457aeee3928fd6171
````

## Release Note

### v4.4.0

- 支持数据源类型Hive

### v4.3.0

- 支持数据库Mysql,Oracle
- 支持行级权限
- 支持Result分批获取

## 连接参数说明

url格式：

```
jdbc:dataphin://host:port/catalog?[currentschema=schema][&user=UserName][&password=PassWord][&tenant_id=TenantID][&delegation_uid=UserName][&engine=spark][&log_level=debug][&connect_timeout=20][&ssl=true]
```

| 参数名称            | 说明                                                                         |
|-----------------|:---------------------------------------------------------------------------|
| host            | dataphin openapi 域名                                                        |
| port            | 端口号，默认为80，该端口会根据ssl参数动态调整，如果ssl=true，则端口为443                               |
| catalog         | dataphin catalog，如果使用某个项目则为项目英文名；如果使用物理数据源则为物理数据源code                      |
| username        | Dataphin平台的AccessKey ID，或Dataphin个人用户的AccessKey ID                         |
| currentschema   | 物理数据源的schema，如pg数据库，可以指定schema，如果数据库没schema的概念则忽略                          |
| password        | Dataphin平台的AccessKey，或Dataphin个人用户的AccessKey                               |
| tenant_id       | 租户ID，主要用于多引擎多租户的场景                                                         |
| delegation_uid  | 代理用户名称，使用平台 AK 可代理某个用户连接                                                   |
| engine          | 指定SQL执行引擎类型，如果计算源是Hadoop类型且计算源上配置了Impala或者spark，engine可选为hive，impala，spark |
| ssl             | 是否开启ssl,如果开启使用https协议，否则使用http协议                                           |
| log_level       | 日志级别，支持debug,info,warn,error                                               |
| connect_timeout | 连接超时时间，单位秒                                                                 |

## 使用示例

### Maven

如果要使用Maven，请添加如下依赖，目前dataphin-jdbc驱动暂未上传到公共仓库，需要手动下载并导入本地maven仓库。

```xml

<dependencies>
    <dependency>
        <groupId>com.aliyun.dataphin</groupId>
        <artifactId>dataphin-jdbc</artifactId>
        <version>${version}</version>
    </dependency>
</dependencies>

```

### Java

```java
public class DataphinJdbcTest {
    public static void main(String[] args) throws Exception {
        String url = "jdbc:dataphin://host:port/catalog?[&tenant_id=TenantID][&ssl=true]";
        String username = "xxxxxx";
        String password = "xxxxxx";
        Class.forName("com.aliyun.dataphin.jdbc.DataphinDriver");
        try (Connection conn = DriverManager.getConnection(url, username, password);
             Statement statement = conn.createStatement()) {

            //query timeout 需要小于60s
            statement.setQueryTimeout(30000);
            String querySql = "select * from data_share_test.data_share_table1 limit 10;";
            ResultSet resultSet = statement.executeQuery(querySql);
            while (resultSet.next()) {
                System.out.print("Column 1 returned ");
                System.out.println(resultSet.getString(1));
            }
            ResultSetPrinter.printResultSet(resultSet);
            resultSet.close();
        }
    }
}
```

### 数据库管理工具

```
如果要使用Datagrip、DBeaver等数据库管理工具连接Dataphin，需要先在Dataphin中创建物理数据源或项目，并配置好连接信息。
然后下载Dataphin-JDBC驱动包，在工具中添加驱动，并选择对应的物理数据源。
```